@@ -79,7 +79,7 @@ class StreamReader:
         if not self.__magic:
             self.__magic = read_magic(self.__stream)
 
-        while self.__footer == None:
+        while self.__footer is None:
             opcode = self.__stream.read1()
             length = self.__stream.read8()
             count = self.__stream.count
@@ -97,16 +97,16 @@ class StreamReader:
                 self.__footer = record
                 read_magic(self.__stream)
 
-    def __init__(self, input: Union[str, RawIOBase, BufferedReader]):
+    def __init__(self, input: Union[str, BytesIO, RawIOBase, BufferedReader]):
         """
         input: The input stream from which to read records.
         """
-        if isinstance(input, BufferedReader):
-            self.__stream = ReadDataStream(input)
-        elif isinstance(input, str):
+        if isinstance(input, str):
             self.__stream = ReadDataStream(open(input, "rb"))
-        else:
+        elif isinstance(input, RawIOBase):
             self.__stream = ReadDataStream(BufferedReader(input))
+        else:
+            self.__stream = ReadDataStream(input)
         self.__footer: Optional[Footer] = None
         self.__magic = False
 
